@@ -311,6 +311,7 @@ append_service_tree (GUPnPServiceInfo *info,
         if (id) {
                 GUPnPServiceIntrospection *introspection;
                 GtkTreeIter                service_iter;
+                GError                    *error;
 
                 gtk_tree_store_insert_with_values (store,
                                                    &service_iter,
@@ -319,14 +320,26 @@ append_service_tree (GUPnPServiceInfo *info,
                                                    1, id,
                                                    2, info, -1);
 
+                error = NULL;
                 introspection = gupnp_service_info_get_introspection (info,
-                                                                      NULL);
+                                                                      &error);
                 if (introspection) {
                         append_introspection (GUPNP_SERVICE_PROXY (info),
                                               introspection,
                                               store,
                                               &service_iter);
                         g_object_unref (introspection);
+                } else if (error) {
+                        char *scpd_url;
+
+                        scpd_url = gupnp_service_info_get_scpd_url (info);
+                        g_warning (
+                           "Failed to create introspection from '%s': %s",
+                           scpd_url,
+                           error->message);
+
+                        g_free (scpd_url);
+                        g_error_free (error);
                 }
 
                 g_free (id);
@@ -438,19 +451,15 @@ setup_device_treeview (GtkWidget    *treeview,
         GtkCellRenderer   *renderer;
         GtkTreeViewColumn *column;
 
-        renderer = gtk_cell_renderer_pixbuf_new ();
-        column = gtk_tree_view_column_new_with_attributes (
-                        "icon",
-                        renderer,
-                        "pixbuf", 0,
-                        NULL);
-        gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-        gtk_tree_view_insert_column (GTK_TREE_VIEW (treeview),
-                                     column,
-                                     0);
-
         setup_treeview (treeview, model, headers, render_index);
 
+        column = gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), 0);
+        renderer = gtk_cell_renderer_pixbuf_new ();
+        gtk_tree_view_column_pack_start (column, renderer, FALSE);
+        gtk_tree_view_column_add_attribute (column,
+                                            renderer,
+                                            "pixbuf", 0);
+
         selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
         g_assert (selection != NULL);
         g_signal_connect (selection,
